.Reservation_area{
    padding-top: 140px;
    padding-bottom: 130px;
    position: relative;
    .rev_icon_3{
        position: absolute;
        left: 2%;
        bottom: 4%;
    }
    .rev_icon_1{
        position: absolute;
        top: 2%;
        right: 4%;
    }
    .rev_icon_2{
        position: absolute;
        bottom: -12%;
        right: 4%;
    }
    @media #{$mobile_device} {
        padding: 50px 15px;
    }
    @media #{$tablet_device} {
        padding: 50px 0;
    }
    @media #{$mid_device} {
        padding: 80px 0;
    }
    .book_Form{
        margin-bottom: 30px;
        background: #DB9A64;
        padding: 34px 40px;
        @media #{$mobile_device} {
            padding: 20px;
        }
        h3{
           font-size: 35px;;
           font-family: $font2;
           font-weight: 700;
           color: #fff;
           margin-bottom: 40px;
        }
        .input_field{
            
            input{
                width: 100%;
                height: 45px;
                border: 1px solid rgba(255,255,255,.30);
                background: transparent ;
                font-size: 14px;
                color: #fff;
                padding-left: 15px;
                &:focus{
                    outline: none;
                }
                &::placeholder{
                    color: #fff;
                    font-size: 14px;
                }
            }
        }
        .sumbit_btn{
            width: 100%;
            background: #BB8151;
            display: block;
            padding: 11px;
            color: #fff;
            font-size: 14px;
            font-weight: 500;
            border: none;
            cursor: pointer;
            &:hover{
                background: #B08151;
            }
        }
        .single_add{
            margin-top: 30px;
            .icon{
                margin-right: 14px;
            }
            .ifno{
                h4{
                    font-weight: 300;
                    font-family: $font1;
                    color: #fff;
                    margin-bottom: 0;
                }
                p{
                    margin-bottom: 0;
                    color: #fff;
                    font-size: 14px;
                    font-weight: 400;
                    font-family: $font1;
                }
            }
        }
    }
    .map_area{
        margin-bottom: 30px;
    }
    .gj-datepicker.gj-datepicker-md.gj-unselectable span {
        color: #fff;
        top: 14px;
        font-size: 14px;
    }
    .nice-select {
        width: auto;
        height: 45px;
        border-radius: 0;
        border: 1px solid rgba(255,255,255,.30);
        background: transparent;
        color: #fff;
        line-height: 45px;
        width: 100%;
        margin-bottom: 15px;
    }
    .nice-select .option {
        cursor: pointer;
        font-weight: 400;
        line-height: 40px;
        list-style: none;
        min-height: 40px;
        outline: none;
        padding-left: 18px;
        padding-right: 29px;
        text-align: left;
        -webkit-transition: all 0.2s;
        transition: all 0.2s;
        color: #000;
        font-size: 14px;
    }
}

.mb_15{
    margin-bottom: 15px;
}

.gj-picker.gj-picker-md.datepicker.gj-unselectable .fa-chevron-left{
    position: absolute;
    left: 30px;
    top: 16px;
}